@@ -13,7 +13,7 @@ from shapely.wkt import dumps
 
 from pyiem import reference
 from pyiem.util import LOG
-from pyiem.exceptions import TextProductException
+from pyiem.exceptions import TextProductException, InvalidPolygon
 from pyiem.nws import ugc, vtec, hvtec
 
 
@@ -91,8 +91,6 @@ PDS_RE = re.compile(
     r"THIS\s+IS\s+A\s+PARTICULARLY\s+DANGEROUS\s+SITUATION", re.I
 )
 
-# http://www.nws.noaa.gov/os/notification/pns11mixedcase.txt
-# DISALLOWED_CHARS = re.compile(r'[^\x40-\x7F]')
 KNOWN_BAD_TTAAII = ["KAWN"]
 
 
@@ -137,6 +135,8 @@ def str2polygon(strdata):
         return None
     if pts[0][0] != pts[-1][0] and pts[0][1] != pts[-1][1]:
         pts.append(pts[0])
+    if len(pts) < 3:
+        raise InvalidPolygon(f"Less than three points for polygon {pts}")
     return Polygon(pts)
 
 
@@ -184,17 +184,54 @@ def date_tokens2datetime(tokens):
     return z, tz, now.replace(tzinfo=timezone.utc)
 
 
+def qc_is_emergency(seg):
+    """Belt + Suspenders check that this segment is an emergency."""
+    ffdt = seg.flood_tags.get("FLASH FLOOD DAMAGE THREAT")
+    # NOOPS
+    if (
+        not seg.is_emergency
+        and seg.damagetag != "CATASTROPHIC"
+        and ffdt != "CATASTROPHIC"
+    ):
+        return
+    # Auto qualifier
+    tag_confirms = "CATASTROPHIC" in [seg.damagetag, ffdt]
+    if tag_confirms:
+        seg.is_emergency = True
+        return
+    # Oh, we have work to do
+    has_tags = seg.damagetag is not None or ffdt is not None
+    # tags do not confirm the emergency
+    if seg.is_emergency and has_tags and not tag_confirms:
+        seg.tp.warnings.append(
+            "Segment indicated emergency, but tags negated it.\n"
+            f"tag_confirms: {tag_confirms} damagetag: {seg.damagetag} "
+            f"ffdt: {ffdt}"
+        )
+        seg.is_emergency = False
+        return
+    # this segment is a CAN, EXP VTEC sole action
+    if seg.is_emergency and seg.vtec and seg.vtec[0].action in ["CAN", "EXP"]:
+        seg.tp.warnings.append(
+            "Segment indicated emergency, but VTEC action is expiring."
+        )
+        seg.is_emergency = False
+
+
 class TextProductSegment:
-    """ A segment of a Text Product """
+    """A segment of a Text Product"""
 
     def __init__(self, text, tp):
-        """ Constructor """
+        """Constructor"""
         self.unixtext = text
         self.tp = tp  # Reference to parent
-        self.ugcs, self.ugcexpire = ugc.parse(
-            text, tp.valid, ugc_provider=tp.ugc_provider
-        )
         self.vtec = vtec.parse(text)
+        self.ugcs, self.ugcexpire = ugc.parse(
+            text,
+            tp.valid,
+            ugc_provider=tp.ugc_provider,
+            is_firewx=any(v.phenomena == "FW" for v in self.vtec),
+        )
         self.headlines = self.parse_headlines()
         self.hvtec = hvtec.parse(text, tp=tp)
 
@@ -207,7 +244,11 @@ class TextProductSegment:
 
         #
         self.giswkt = None
-        self.sbw = self.process_latlon()
+        try:
+            self.sbw = self.process_latlon()
+        except InvalidPolygon as exp:
+            tp.warnings.append(str(exp))
+            self.sbw = None
 
         # tags
         self.windtag = None
@@ -226,39 +267,39 @@ class TextProductSegment:
         self.is_emergency = False
         self.is_pds = False
         self.process_tags()
-
+        qc_is_emergency(self)
         self.bullets = self.process_bullets()
 
     def get_ugcs_tuple(self):
-        """ Helper to return a tuple useful for SQL. """
+        """Helper to return a tuple useful for SQL."""
         return tuple([str(u) for u in self.ugcs])
 
     def get_hvtec_nwsli(self):
-        """ Return the first hvtec NWSLI entry, if it exists """
+        """Return the first hvtec NWSLI entry, if it exists"""
         if not self.hvtec:
             return None
         return self.hvtec[0].nwsli.id
 
     def get_hvtec_cause(self):
-        """ Return the first hvtec cause entry, if it exists """
+        """Return the first hvtec cause entry, if it exists"""
         if not self.hvtec:
             return None
         return self.hvtec[0].cause
 
     def get_hvtec_severity(self):
-        """ Return the first hvtec severity entry, if it exists """
+        """Return the first hvtec severity entry, if it exists"""
         if not self.hvtec:
             return None
         return self.hvtec[0].severity
 
     def get_hvtec_record(self):
-        """ Return the first hvtec record entry, if it exists """
+        """Return the first hvtec record entry, if it exists"""
         if not self.hvtec:
             return None
         return self.hvtec[0].record
 
     def svs_search(self):
-        """ Special search the product for special text """
+        """Special search the product for special text"""
         sections = self.unixtext.split("\n\n")
         for section in sections:
             if TORNADO.findall(section):
@@ -266,7 +307,7 @@ class TextProductSegment:
         return ""
 
     def process_bullets(self):
-        """ Figure out the bulleted segments """
+        """Figure out the bulleted segments"""
         parts = re.findall(r"^\*([^\*]*)", self.unixtext, re.M | re.DOTALL)
         bullets = []
         for part in parts:
@@ -278,11 +319,11 @@ class TextProductSegment:
         return bullets
 
     def process_tags(self):
-        """ Find various tags in this segment """
+        """Find various tags in this segment"""
         nolf = self.unixtext.replace("\n", " ")
         res = EMERGENCY_RE.findall(nolf)
         if res:
-            # TODO: this can be based off the IBW Tags too
+            # We later double check this based on the found tags
             self.is_emergency = True
         res = PDS_RE.findall(nolf)
         if res:
@@ -442,7 +483,7 @@ class TextProductSegment:
         return poly
 
     def process_time_mot_loc(self):
-        """ Try to parse the TIME...MOT...LOC """
+        """Try to parse the TIME...MOT...LOC"""
         pos = self.unixtext.find("TIME...MOT...LOC")
         if pos == -1:
             return
@@ -491,7 +532,7 @@ class TextProductSegment:
         self.tml_dir = int(gdict["dir"])
 
     def parse_headlines(self):
-        """ Find headlines in this segment """
+        """Find headlines in this segment"""
         headlines = re.findall(
             r"^\.\.\.(.*?)\.\.\.[ ]?\n\n", self.unixtext, re.M | re.S
         )
@@ -578,7 +619,7 @@ class TextProduct:
                 yield (segment, segment.ugcs, _vtec)
 
     def is_resent(self):
-        """ Check to see if this product is a ...RESENT product """
+        """Check to see if this product is a ...RESENT product"""
         return self.unixtext.find("...RESENT") > 0
 
     def is_correction(self):
@@ -603,7 +644,7 @@ class TextProduct:
         return False
 
     def get_channels(self):
-        """ Return a list of channels """
+        """Return a list of channels"""
         res = [self.afos, f"{self.afos[:3]}..."]
         if self.afos[:3] in ["TCU", "TCD", "TCM", "TCP", "TWO"]:
             res.append(self.afos[:5])
@@ -680,19 +721,16 @@ class TextProduct:
         )
 
     def parse_segments(self):
-        """ Split the product by its $$ """
+        """Split the product by its $$"""
         segs = self.unixtext.split("$$")
         for seg in segs:
             self.segments.append(TextProductSegment(seg, self))
 
     def get_product_id(self):
-        """ Get an identifier of this product used by the IEM """
-        pid = "%s-%s-%s-%s" % (
-            self.valid.strftime("%Y%m%d%H%M"),
-            self.source,
-            self.wmo,
-            self.afos,
-        )
+        """Get an identifier of this product used by the IEM"""
+        pid = f"{self.valid:%Y%m%d%H%M}-{self.source}-{self.wmo}-{self.afos}"
+        if self.bbb:
+            pid += f"-{self.bbb}"
         return pid.strip()
 
     def _parse_valid(self, provided_utcnow):
@@ -757,7 +795,7 @@ class TextProduct:
         self.z, self.tz, self.valid = date_tokens2datetime(tokens[0])
 
     def parse_wmo(self):
-        """ Parse things related to the WMO header"""
+        """Parse things related to the WMO header"""
         search = WMO_RE.search(self.unixtext[:100])
         if search is None:
             raise TextProductException(
@@ -793,7 +831,7 @@ class TextProduct:
         return affected_wfos
 
     def parse_afos(self):
-        """ Figure out what the AFOS PIL is """
+        """Figure out what the AFOS PIL is"""
         # at most, only look at the top four lines, skipping the first
         data = "\n".join(
             [line.strip() for line in self.sections[0].split("\n")[1:4]]
