@@ -40,6 +40,11 @@ REGIMES = [
     "WEATHER ITEM   OBSERVED TIME   NORMAL DEPARTURE",
     "WEATHER ITEM   OBSERVED NORMAL DEPARTURE",
     "WEATHER ITEM   OBSERVED TIME   RECORD NORMAL DEPARTURE LAST",
+    (
+        "WEATHER ITEM   OBSERVED    TIME     RECORD    YEAR    NORMAL    "
+        "DEPARTURE    LAST"
+    ),
+    "WEATHER ITEM   OBSERVED RECORD YEAR     LAST",
 ]
 # label, value, time, record, year, normal, departure, last
 COLS = [
@@ -61,6 +66,8 @@ COLS = [
     [16, 23, 30, None, None, 37, 44, None],
     [16, 23, None, None, None, 30, 37, None],
     [16, 23, 30, 37, None, 44, 51, 60],
+    [16, 23, 34, 40, 50, 58, 67, 80],
+    [16, 23, None, 30, 35, None, None, 44],
 ]
 # Allow manual provision of IDS
 HARDCODED = {}
@@ -121,7 +128,7 @@ def update_iemaccess(txn, entry):
 
 
 def trace_r(val):
-    """ Convert our value back into meaningful string """
+    """Convert our value back into meaningful string"""
     if val is None:
         return "Missing"
     if val == TRACE_VALUE:
@@ -138,7 +145,7 @@ def get_number_year(text):
 
 
 def get_number(text):
-    """ Convert a string into a number, preferable a float! """
+    """Convert a string into a number, preferable a float!"""
     if text is None:
         return None
     text = text.strip()
@@ -162,7 +169,7 @@ def get_number(text):
 
 
 def convert_key(text):
-    """ Convert a key value to something we store """
+    """Convert a key value to something we store"""
     if text is None:
         return None
     if text == "YESTERDAY":
@@ -178,7 +185,7 @@ def convert_key(text):
 
 
 def make_tokens(regime, line):
-    """ Turn a line into tokens based on a regime """
+    """Turn a line into tokens based on a regime"""
     mycols = COLS[regime]
     tokens = []
     pos = 0
@@ -225,12 +232,12 @@ def parse_snowfall(regime, lines, data):
             ) == 4:
                 n = get_number_year(lines[linenum + 1])
                 if n is not None:
-                    data["snow_today_record_years"].append(n)
+                    data.setdefault("snow_today_record_years", []).append(n)
                 linenum += 1
 
 
 def parse_precipitation(regime, lines, data):
-    """ Parse the precipitation data """
+    """Parse the precipitation data"""
     for linenum, line in enumerate(lines):
         if len(line.strip()) < 20:
             continue
@@ -257,7 +264,7 @@ def parse_precipitation(regime, lines, data):
             ) == 4:
                 n = get_number_year(lines[linenum + 1])
                 if n is not None:
-                    data["precip_today_record_years"].append(n)
+                    data.setdefault("precip_today_record_years", []).append(n)
                 linenum += 1
 
 
@@ -294,7 +301,10 @@ def parse_temperature(prod, regime, lines, data):
             line2 = lines[linenum + 1].strip()
             n = get_number_year(line2)
             if n is not None:
-                data[f"temperature_{key}_record_years"].append(n)
+                data.setdefault(
+                    f"temperature_{key}_record_years",
+                    [],
+                ).append(n)
             else:
                 prod.warnings.append(f"Found invalid year |{line2}|")
             linenum += 1
@@ -312,7 +322,7 @@ def parse_sky_coverage(lines, data):
 
 
 def parse_headline(section):
-    """ Figure out when this product is valid for """
+    """Figure out when this product is valid for"""
     tokens = HEADLINE_RE.findall(section.replace("\n", " "))
     myfmt = "%b %d %Y" if len(tokens[0][1].split()[0]) == 3 else "%B %d %Y"
     cli_valid = datetime.datetime.strptime(tokens[0][1], myfmt).date()
@@ -464,7 +474,7 @@ class CLIProduct(TextProduct):
     def __init__(
         self, text, utcnow=None, ugc_provider=None, nwsli_provider=None
     ):
-        """ constructor """
+        """constructor"""
         TextProduct.__init__(self, text, utcnow, ugc_provider, nwsli_provider)
         # Hold our parsing results as an array of dicts
         self.data = []
@@ -522,7 +532,7 @@ class CLIProduct(TextProduct):
         return sections
 
     def compute_diction(self, text):
-        """ Try to determine what we have for a format """
+        """Try to determine what we have for a format"""
         tokens = re.findall("^WEATHER ITEM.*$", text, re.M)
         diction = tokens[0].strip()
         if diction not in REGIMES:
@@ -533,7 +543,7 @@ class CLIProduct(TextProduct):
         self.regime = REGIMES.index(diction)
 
     def get_jabbers(self, uri, _=None):
-        """ Override the jabber message formatter """
+        """Override the jabber message formatter"""
         url = f"{uri}?pid={self.get_product_id()}"
         res = []
         xtra = {
@@ -580,7 +590,7 @@ class CLIProduct(TextProduct):
         return res
 
     def parse_data(self, section):
-        """ Actually do the parsing of this silly format """
+        """Actually do the parsing of this silly format"""
         data = {}
         # We need to first search down the section to look for where the
         # first TEMPERATURE section starts.
@@ -596,7 +606,11 @@ class CLIProduct(TextProduct):
         sections = meat.split("\n\n")
         for _section in sections:
             lines = _section.split("\n")
-            if lines[0] in ["TEMPERATURE (F)", "TEMPERATURE"]:
+            if lines[0] in [
+                "TEMPERATURE (F)",
+                "TEMPERATURE",
+                "TEMPERATURE(F)",
+            ]:
                 parse_temperature(self, self.regime, lines, data)
             elif lines[0] in ["PRECIPITATION (IN)", "PRECIPITATION"]:
                 parse_precipitation(self.regime, lines, data)
