@@ -11,7 +11,7 @@ from pyiem.models.taf import TAFForecast, TAFReport, SkyCondition, WindShear
 TEMPO_TIME = re.compile(r"^(?P<ddhh1>\d{4})/(?P<ddhh2>\d{4}) ")
 STID_VALID = re.compile(r"(?P<station>[A-Z0-9]{4}) (?P<ddhhmi>\d{6})Z")
 WIND_RE = re.compile(r"(?P<dir>\d{3})(?P<sknt>\d{2,3})G?(?P<gust>\d{2,3})?KT")
-VIS_RE = re.compile(r" P?(?P<miles>[1-6])?\s?(?P<frac>\d/\d+)?SM")
+VIS_RE = re.compile(r" (?P<over>P?)(?P<miles>[1-6])?\s?(?P<frac>\d/\d+)?SM")
 WX_RE = re.compile(r"^([\-\+A-Z]+)$")
 CLOUD_RE = re.compile(r" (?P<skyc>SCT|OVC|VV|BKN|FEW)(?P<skyl>\d{3})")
 SHEAR_RE = re.compile(
@@ -31,6 +31,8 @@ def add_forecast_info(fx, text):
     if m:
         d = m.groupdict()
         fx.visibility = int(d["miles"] or 0)
+        if d.get("over") == "P" and fx.visibility == 6:
+            fx.visibility = reference.TAF_VIS_OVER_6SM
         if d["frac"] is not None:
             tokens = d["frac"].split("/")
             fx.visibility += float(tokens[0]) / float(tokens[1])
@@ -88,6 +90,8 @@ def ddhhmi2valid(prod, text):
         valid = prod.valid.replace(day=dd, hour=0, minute=mi) + timedelta(
             days=1
         )
+    elif hr < 0 or hr > 23:
+        raise ValueError(f"Found invalid hr: {hr} from '{text}'")
     else:
         valid = prod.valid.replace(hour=hr, minute=mi)
     # Next month
@@ -148,12 +152,12 @@ class TAFProduct(TextProduct):
     def __init__(
         self, text, utcnow=None, ugc_provider=None, nwsli_provider=None
     ):
-        """ constructor """
+        """constructor"""
         TextProduct.__init__(self, text, utcnow, ugc_provider, nwsli_provider)
         self.data = parse_prod(self)
 
     def get_channels(self):
-        """ Return a list of channels """
+        """Return a list of channels"""
         return [f"TAF{self.data.station[1:]}", "TAF...", f"{self.source}.TAF"]
 
     def sql(self, txn):
@@ -196,7 +200,7 @@ class TAFProduct(TextProduct):
             )
 
     def get_jabbers(self, uri, _uri2=None):
-        """ Get the jabber variant of this message """
+        """Get the jabber variant of this message"""
         res = []
         url = f"{uri}?pid={self.get_product_id()}"
         aaa = "TAF"
@@ -232,5 +236,5 @@ class TAFProduct(TextProduct):
 
 
 def parser(text, utcnow=None, ugc_provider=None, nwsli_provider=None):
-    """ Helper function """
+    """Helper function"""
     return TAFProduct(text, utcnow, ugc_provider, nwsli_provider)
