@@ -6,7 +6,7 @@ from datetime import timezone, date, timedelta
 import math
 
 try:
-    from zoneinfo import ZoneInfo
+    from zoneinfo import ZoneInfo  # type: ignore
 except ImportError:
     from backports.zoneinfo import ZoneInfo
 
@@ -48,7 +48,7 @@ def get_summary_table(valid):
         valid.month == 1 and valid.day < 3
     ):
         return "summary"
-    return "summary_%s" % (valid.year,)
+    return f"summary_{valid.year}"
 
 
 def bounded(val, floor, ceiling):
@@ -134,10 +134,15 @@ def summary_update(txn, data):
         else coalesce(%(coop_tmpf)s, coop_tmpf) end,
     coop_valid = %(coop_valid)s,
     et_inch = %(et_inch)s,
+    report = coalesce(%(report)s, report),
     max_rh = case when %(null_max_rh)s is null then null
         else greatest(%(max_rh)s, %(relh)s, max_rh) end,
     min_rh = case when %(null_min_rh)s is null then null
         else least(%(min_rh)s, %(relh)s, min_rh) end,
+    max_rstage = case when %(null_max_rstage)s is null then null
+        else greatest(%(max_rstage)s, %(rstage)s, max_rstage) end,
+    min_rstage = case when %(null_min_rstage)s is null then null
+        else least(%(min_rstage)s, %(rstage)s, min_rstage) end,
     srad_mj = %(srad_mj)s,
     avg_sknt = case when %(null_avg_sknt)s is null then null
         else coalesce(%(avg_sknt)s, avg_sknt) end,
@@ -150,7 +155,7 @@ def summary_update(txn, data):
 
 
 class Observation:
-    """ my observation object """
+    """my observation object"""
 
     def __init__(self, station, network, valid):
         """
@@ -315,6 +320,7 @@ class Observation:
         peak_wind_gust = %(peak_wind_gust)s,
         peak_wind_drct = %(peak_wind_drct)s,
         peak_wind_time = %(peak_wind_time)s,
+        snowdepth = %(snowdepth)s,
         updated = now()
         WHERE c.iemid = %(iemid)s and %(valid)s >= c.valid """
         if not self.data["_isdaily"] and not skip_current:
@@ -331,7 +337,7 @@ class Observation:
             max_tmpf_24hr, min_tmpf_24hr, wxcodes, battery,
             ice_accretion_1hr, ice_accretion_3hr, ice_accretion_6hr,
             water_tmpf, feel, peak_wind_gust, peak_wind_drct,
-            peak_wind_time) VALUES(
+            peak_wind_time, snowdepth) VALUES(
             %(iemid)s, %(tmpf)s, %(dwpf)s, %(drct)s, %(sknt)s,
             %(indoor_tmpf)s, %(tsf0)s, %(tsf1)s, %(tsf2)s, %(tsf3)s,
             %(rwis_subf)s, %(scond0)s, %(scond1)s, %(scond2)s, %(scond3)s,
@@ -348,7 +354,7 @@ class Observation:
             %(ice_accretion_1hr)s, %(ice_accretion_3hr)s,
             %(ice_accretion_6hr)s,
             %(water_tmpf)s, %(feel)s, %(peak_wind_gust)s, %(peak_wind_drct)s,
-            %(peak_wind_time)s
+            %(peak_wind_time)s, %(snowdepth)s
             )
             """
             if not self.data["_isdaily"]:
