@@ -33,7 +33,6 @@ import requests
 from metpy.calc import wind_components
 from metpy.units import units
 import numpy as np
-import pandas as pd
 import geopandas as gpd
 from shapely.geometry import shape
 from scipy.signal import convolve2d
@@ -56,6 +55,7 @@ from pyiem.plot.util import (
     mask_outside_geom,
     draw_logo,
     fitbox,
+    ramp2df,
 )
 from pyiem.reference import (  # noqa: F401  # pylint: disable=unused-import
     LATLON,
@@ -70,13 +70,11 @@ from pyiem.reference import (  # noqa: F401  # pylint: disable=unused-import
     Z_FRAME,
     TWITTER_RESOLUTION_INCH,
 )
-from pyiem.util import ssw, LOG, utc, exponential_backoff
+from pyiem.util import ssw, LOG, utc, exponential_backoff, load_geodf
 from pyiem.plot.colormaps import stretch_cmap
 
 # geopandas currently emits this as parquet is unstable.
 warnings.filterwarnings("ignore", message=".*implementation of Parquet.*")
-# we ran the cartopy/tools downloader
-cartopy.config["pre_existing_data_dir"] = "/opt/miniconda3/cartopy_data/"
 # Set a saner default for apache et al
 cartopy.config["data_dir"] = "/tmp/"
 
@@ -95,45 +93,13 @@ def load_bounds(filebase):
     Returns:
       numpy 2d array of the data
     """
-    fn = "%s/%s.npy" % (DATADIR, filebase)
+    fn = os.path.join(DATADIR, f"{filebase}.npy")
     if not os.path.isfile(fn):
         LOG.info("load_bounds(%s) is missing!", fn)
-        return
+        return None
     return np.load(fn)
 
 
-def load_pickle_pd(filename):
-    """Load a pickled pandas dataframe
-
-    Args:
-      filename(str): The filename to load, relative to project data/
-
-    Returns:
-      pandas.DataFrame
-    """
-    fn = "%s/%s" % (DATADIR, filename)
-    if not os.path.isfile(fn):
-        LOG.info("load_pickle_pd(%s) failed, file is missing", fn)
-        return
-    return pd.read_pickle(fn)
-
-
-def load_geodf(filename):
-    """Load GeoPandas GeoDataFrame.
-
-    Args:
-      filename(str): The filename to load, contained in project data/
-
-    Returns:
-      GeoDataFrame
-    """
-    fn = "%s/geodf/%s.parquet" % (DATADIR, filename)
-    if not os.path.isfile(fn):
-        LOG.info("load_geodf(%s) failed, file is missing!", fn)
-        return gpd.GeoDataFrame()
-    return gpd.read_parquet(fn)
-
-
 class MapPlot:
     """An object representing a cartopy plot.
 
@@ -219,7 +185,7 @@ class MapPlot:
                 states = load_geodf("us_states")
                 _a.add_geometries(
                     states["geom"].values,
-                    crs=ccrs.PlateCarree(),
+                    crs=LATLON,
                     lw=1.0,
                     edgecolor=kwargs.get("statebordercolor", "k"),
                     facecolor="None",
@@ -253,15 +219,12 @@ class MapPlot:
             self.fig.text(
                 0.01,
                 0.03,
-                ("%s :: generated %s")
-                % (
-                    kwargs.get("caption", "Iowa Environmental Mesonet"),
-                    datetime.datetime.now().strftime("%d %B %Y %I:%M %p %Z"),
-                ),
+                f"{kwargs.get('caption', 'Iowa Environmental Mesonet')} :: "
+                f"generated {datetime.datetime.now():%d %B %Y %I:%M %p %Z}",
             )
 
     def close(self):
-        """ Close the figure in the case of batch processing """
+        """Close the figure in the case of batch processing"""
         plt.close()
 
     def draw_usdm(self, valid=None, filled=True, hatched=False):
@@ -288,13 +251,11 @@ class MapPlot:
             valid = valid.strftime("%Y-%m-%d")
         elif isinstance(valid, datetime.datetime):
             valid = valid.strftime("%Y-%m-%d")
-        url = ("http://mesonet.agron.iastate.edu/geojson/usdm.py?date=%s") % (
-            valid,
-        )
+        url = f"http://mesonet.agron.iastate.edu/geojson/usdm.py?date={valid}"
         try:
             req = requests.get(url, timeout=30)
         except requests.ConnectionError as exp:
-            warnings.warn("draw_usdm IEM USDM Webservice failed: %s" % (exp,))
+            warnings.warn(f"draw_usdm IEM USDM Webservice failed: {exp}")
             return None
         df = gpd.GeoDataFrame().from_features(req.json())
         lw = 1 if filled else 4.0
@@ -307,7 +268,7 @@ class MapPlot:
             ec = color if not filled else "k"
             self.ax.add_geometries(
                 [geom],
-                ccrs.PlateCarree(),
+                LATLON,
                 facecolor="None",
                 edgecolor=ec,
                 linewidth=lw,
@@ -316,7 +277,7 @@ class MapPlot:
             if filled:
                 self.ax.add_geometries(
                     [geom],
-                    ccrs.PlateCarree(),
+                    LATLON,
                     facecolor=fc,
                     alpha=0.5,
                     edgecolor="None",
@@ -325,7 +286,7 @@ class MapPlot:
             elif hatched:
                 self.ax.add_geometries(
                     [geom],
-                    ccrs.PlateCarree(),
+                    LATLON,
                     facecolor="None",
                     hatch=hatches[row["dm"]],
                     edgecolor=color,
@@ -391,7 +352,7 @@ class MapPlot:
             self.ax.text(
                 0.815,
                 0.99,
-                "USDM %s" % (usdm_valid,),
+                f"USDM {usdm_valid}",
                 color="w",
                 transform=self.ax.transAxes,
                 va="top",
@@ -416,6 +377,7 @@ class MapPlot:
         """
         if self.cax is None:
             return
+        self.cax.set_frame_on(True)
         extend = kwargs.get("extend", "both")
         # Do we need to muck with the cmap
         # pylint: disable=W0212
@@ -455,7 +417,7 @@ class MapPlot:
             try:
                 return "%g" % (val,)
             except TypeError:
-                return "%s" % (val,)
+                return f"{val}"
 
         cb2.ax.set_yticklabels(list(map(_myrepr, clevlabels[stride])))
         # Attempt to quell offset that sometimes appears with large numbers
@@ -471,7 +433,7 @@ class MapPlot:
 
         if "units" in kwargs:
             self.fig.text(
-                0.99, 0.03, "data units :: %s" % (kwargs["units"],), ha="right"
+                0.99, 0.03, f"data units :: {kwargs['units']}", ha="right"
             )
 
         title = kwargs.get("title")
@@ -605,7 +567,7 @@ class MapPlot:
                     offsets[6] if skycoverage is not None else offsets[5]
                 )
                 self.ax.annotate(
-                    "%s" % (val,),
+                    f"{val}",
                     xy=(x, y),
                     ha=ha,
                     va=va,
@@ -809,7 +771,7 @@ class MapPlot:
                 zorder=z,
                 va="center" if not showmarker else "bottom",
                 ha=ha,
-                transform=ccrs.PlateCarree(),
+                transform=LATLON,
             )
             bbox = t0.get_window_extent(self.fig.canvas.get_renderer())
             if self.debug:
@@ -828,7 +790,7 @@ class MapPlot:
                     marker="+",
                     zorder=z,
                     color="k",
-                    transform=ccrs.PlateCarree(),
+                    transform=LATLON,
                 )
             t0.set_clip_on(True)
             t0.set_path_effects(
@@ -843,7 +805,7 @@ class MapPlot:
 
             if label and label != "":
                 ax.annotate(
-                    "%s" % (label,),
+                    f"{label}",
                     xy=(x, y),
                     ha="center",
                     va="top",
@@ -876,22 +838,20 @@ class MapPlot:
             lats,
             c=colors,
             edgecolors=colors,
-            transform=ccrs.PlateCarree(),
+            transform=LATLON,
             zorder=Z_OVERLAY,
         )
         kwargs.pop("cmap", None)
         self.draw_colorbar(clevs, cmap, norm, **kwargs)
 
     def hexbin(self, lons, lats, vals, clevs, **kwargs):
-        """ hexbin wrapper """
+        """hexbin wrapper"""
         cmap = stretch_cmap(
             kwargs.get("cmap"), clevs, extend=kwargs.get("extend")
         )
         norm = mpcolors.BoundaryNorm(clevs, cmap.N)
 
-        points = self.ax.projection.transform_points(
-            ccrs.PlateCarree(), lons, lats
-        )
+        points = self.ax.projection.transform_points(LATLON, lons, lats)
         _hex = self.ax.hexbin(
             points[:, 0],
             points[:, 1],
@@ -934,7 +894,7 @@ class MapPlot:
             norm=norm,
             cmap=cmap,
             zorder=Z_FILL,
-            transform=ccrs.PlateCarree(),
+            transform=LATLON,
         )
 
         if kwargs.get("clip_on", True):
@@ -982,7 +942,7 @@ class MapPlot:
             geo = s["geom"].values[0]
             ccw = np.asarray(geo.exterior)[::-1]
         else:
-            ccw = load_bounds("%s_ccw" % (sector,))
+            ccw = load_bounds(f"{sector}_ccw")
         # in map coords
         points = self.ax.projection.transform_points(
             ccrs.Geodetic(), ccw[:, 0], ccw[:, 1]
@@ -1068,7 +1028,7 @@ class MapPlot:
             norm=norm,
             zorder=Z_FILL,
             extend="both",
-            transform=ccrs.PlateCarree(),
+            transform=LATLON,
         )
         if kwargs.get("iline", True):
             csl = self.ax.contour(
@@ -1078,7 +1038,7 @@ class MapPlot:
                 clevs,
                 colors="w",
                 zorder=Z_FILL_LABEL,
-                transform=ccrs.PlateCarree(),
+                transform=LATLON,
             )
             if kwargs.get("ilabel", False):
                 self.ax.clabel(
@@ -1154,7 +1114,7 @@ class MapPlot:
         for _a in self.axes:
             _a.add_geometries(
                 cwas["geom"].values,
-                crs=ccrs.PlateCarree(),
+                crs=LATLON,
                 zorder=Z_POLITICAL,
                 facecolor="None",
                 **kwargs,
@@ -1183,25 +1143,25 @@ class MapPlot:
         """Overlay some cities
 
         Args:
-          minarea (int,optional): Minimum Urban Area size (km2) to plot
+          minpop (int,optional): Minimum population to consider for plotting.
           labelbuffer (int): approximate number of pixels to compute overlap
           textsize (int): size of the text
           color (str): color to plot the text with
           outlinecolor (str): color to outline the text with
         """
-        df = load_pickle_pd("pd_cities.pickle")
-        (west, east, south, north) = self.ax.get_extent(crs=ccrs.PlateCarree())
+        gdf = load_geodf("cities")
+        (west, east, south, north) = self.ax.get_extent(crs=LATLON)
 
-        minarea = kwargs.get(
-            "minarea", 500.0 if self.sector in ["nws", "conus"] else 10.0
+        minpop = kwargs.get(
+            "minpop", 50000.0 if self.sector in ["nws", "conus"] else 5000.0
         )
-        df2 = df[
+        df2 = gdf[
             (
-                (df["lat"] > south)
-                & (df["lat"] < north)
-                & (df["lon"] > west)
-                & (df["lon"] < east)
-                & (df["area_km2"] > minarea)
+                (gdf["geom"].y > south)
+                & (gdf["geom"].y < north)
+                & (gdf["geom"].x > west)
+                & (gdf["geom"].x < east)
+                & (gdf["pop_2010"] > minpop)
             )
         ]
         # debug option to test an individual point on the plot
@@ -1209,9 +1169,9 @@ class MapPlot:
         # hack around a API break
         tsz = kwargs.pop("textsize", 16)
         self.plot_values(
-            df2.lon.values,
-            df2.lat.values,
-            df2.name.values,
+            df2["geom"].x,
+            df2["geom"].y,
+            df2["name"].values,
             showmarker=True,
             textsize=tsz,
             **kwargs,
@@ -1226,7 +1186,7 @@ class MapPlot:
         geodf = load_geodf("ugcs_county")
         self.ax.add_geometries(
             geodf["geom"].values,
-            crs=ccrs.PlateCarree(),
+            crs=LATLON,
             facecolor="None",
             edgecolor=color,
             lw=0.4,
@@ -1269,7 +1229,7 @@ class MapPlot:
         tmpfd.close()
         if kwargs.get("pqstr") is not None:
             subprocess.call(
-                "pqinsert -p '%s' %s" % (kwargs.get("pqstr"), tmpfd.name),
+                f"pqinsert -p '{kwargs.get('pqstr')}' {tmpfd.name}",
                 shell=True,
             )
         if kwargs.get("filename") is not None:
@@ -1294,7 +1254,7 @@ class MapPlot:
         try:
             req = requests.get(url, params={"valid": tstamp}, timeout=30)
         except requests.ConnectionError as exp:
-            warnings.warn("overlay_roadcond failed: %s" % (exp,))
+            warnings.warn(f"overlay_roadcond failed: {exp}")
             return None
         df = gpd.GeoDataFrame().from_features(req.json())
         labels = []
@@ -1302,7 +1262,7 @@ class MapPlot:
             for geo in row["geometry"]:
                 self.ax.plot(
                     *geo.xy,
-                    transform=ccrs.PlateCarree(),
+                    transform=LATLON,
                     color=row["color"],
                     linewidth=2 if row["rtype"] > 1 else 4,
                     zorder=Z_OVERLAY2,
@@ -1318,12 +1278,14 @@ class MapPlot:
             framealpha=1,
         ).set_zorder(Z_OVERLAY2 + 5)
 
-    def overlay_nexrad(self, valid=None, product="N0Q"):
+    def overlay_nexrad(self, valid=None, product="N0Q", caxpos=None):
         """Overlay an IEM NEXRAD Composite Image.
 
         Args:
           valid (datetime.datetime): Valid time for NEXRAD overlay.
           product (str): either N0Q or N0R for the mosaic type.
+          caxpos (array-like): `matplotlib.axes.set_position` value for the
+            colorbar.  Defaults to something in the upper-right.
 
         Returns:
           valid time of the NEXRAD, or None if not found.
@@ -1394,7 +1356,7 @@ class MapPlot:
                 resampling=Resampling.nearest,
             )
 
-        ramp = pd.read_csv(f"{DATADIR}/ramps/composite_{product.lower()}.txt")
+        ramp = ramp2df(f"composite_{product.lower()}")
         cmap = mpcolors.ListedColormap(ramp[["r", "g", "b"]].to_numpy() / 256)
         cmap.set_under((0, 0, 0, 0))
         norm = mpcolors.BoundaryNorm(ramp["coloridx"].values, cmap.N)
@@ -1408,7 +1370,9 @@ class MapPlot:
             origin="lower",
         ).set_rasterized(True)
         pos = self.ax.get_position()
-        cax = self.fig.add_axes([pos.x1 - 0.35, pos.y1 - 0.01, 0.35, 0.015])
+        cax = self.fig.add_axes(
+            caxpos or [pos.x1 - 0.35, pos.y1 - 0.01, 0.35, 0.015]
+        )
         cb = mpcolorbar.ColorbarBase(
             cax,
             cmap=cmap,
@@ -1425,16 +1389,7 @@ class MapPlot:
                 for d in ramp.loc[ramp["value"] % 20 == 0]["value"].values
             ]
         )
+        if caxpos is not None:
+            pos = cb.ax.get_position()
         self.fig.text(pos.x1, pos.y1 + 0.005, "dBZ", ha="left")
         return valid
-
-
-def windrose(*args, **kwargs):
-    """Depreciated."""
-    warnings.warn(
-        "windrose() is depreciated, use pyiem.windrose_utils!",
-        DeprecationWarning,
-    )
-    import pyiem.windrose_utils as wru
-
-    return wru.windrose(*args, **kwargs)
