@@ -18,6 +18,18 @@ LOGO_BOUNDS = (0.005, 0.91, 0.08, 0.086)
 LOGOFILES = {"dep": "deplogo.png", "iem": "logo.png"}
 
 
+def ramp2df(name) -> pd.DataFrame:
+    """Loads pyIEM color ramp into a Pandas DataFrame.
+
+    Args:
+      name (str): the name of the bundled color ramp.
+
+    Returns:
+      pandas.DataFrame
+    """
+    return pd.read_csv(f"{DATADIR}/ramps/{name}.txt")
+
+
 def pretty_bins(minval, maxval, bins=8):
     """Return a **smooth** binning that encloses the min and max value.
 
@@ -215,15 +227,6 @@ def sector_setter(mp, axbounds, **kwargs):
             is_geoextent=True,
         )
         mp.axes.append(mp.ax)
-    elif mp.sector in reference.SECTORS:
-        mp.ax = make_axes(
-            axbounds,
-            reference.SECTORS[mp.sector],
-            reference.EPSG[3857],
-            aspect,
-            is_geoextent=True,
-        )
-        mp.axes.append(mp.ax)
     elif mp.sector == "iowawfo":
         mp.ax = make_axes(
             axbounds,
@@ -280,15 +283,34 @@ def sector_setter(mp, axbounds, **kwargs):
                 is_geoextent=True,
             )
             mp.axes.append(mp.ak_ax)
-            # Create HI
+            # Create HI via a glorious hack for now
+            ln = mp.ax.plot(
+                [-95.4, -85.24],
+                [23.3, 27.7],
+                transform=ccrs.PlateCarree(),
+                color="None",
+            )[0]
+            bbox = ln.get_window_extent(mp.fig.canvas.get_renderer())
+            width = mp.fig.canvas.get_width_height()[0]
+            axwidth = (bbox.x1 - bbox.x0) / width
             mp.hi_ax = make_axes(
-                [0.47, 0.055, 0.24, 0.14],
+                [bbox.x0 / width, 0.055, axwidth, 0.14],
                 [-161.0, -154.0, 18.5, 22.5],
                 reference.LATLON,
                 aspect,
                 is_geoextent=True,
             )
             mp.axes.append(mp.hi_ax)
+    # Do last in case of name overlaps above
+    elif mp.sector in reference.SECTORS:
+        mp.ax = make_axes(
+            axbounds,
+            reference.SECTORS[mp.sector],
+            reference.EPSG[3857],
+            aspect,
+            is_geoextent=True,
+        )
+        mp.axes.append(mp.ax)
 
 
 def mask_outside_polygon(poly_verts, ax=None):
