@@ -34,6 +34,7 @@ import cartopy.crs as ccrs
     Z_FRAME,
 ] = range(2, 13)
 
+TAF_VIS_OVER_6SM = 6.01
 TRACE_VALUE = 0.0001
 TWEET_CHARS = 280
 TWITTER_RESOLUTION_INCH = (12.0, 6.75)
@@ -75,9 +76,28 @@ CONUS_NORTH = 49.75
 CONUS_SOUTH = 24.25
 
 SECTORS = {
-    "midwest": [MW_WEST, MW_EAST, MW_SOUTH, MW_NORTH],
+    "conus": [CONUS_WEST, CONUS_EAST, CONUS_SOUTH, CONUS_NORTH],
     "cornbelt": [-99.0, -84.0, 37.17, 45.2],
+    "highplains": [-108, -94, 40, 49.5],
     "iailin": [-97.5, -84.0, 37.0, 44.0],
+    "midwest": [MW_WEST, MW_EAST, MW_SOUTH, MW_NORTH],
+    "northeast": [-87, -66, 36.5, 48],
+    "northwest": [-126, -103.5, 41, 49.5],
+    "southeast": [-95, -74, 24.5, 39],
+    "southernplains": [-109, -88, 25.5, 40],
+    "southwest": [-126, -103.5, 30.8, 41],
+}
+SECTORS_NAME = {
+    "conus": "Contiguous US",
+    "cornbelt": "Corn Belt US",
+    "highplains": "High Plains",
+    "iailin": "IA + IL + IN",
+    "midwest": "Midwestern US",
+    "northeast": "Northeastern US",
+    "northwest": "Northwestern US",
+    "southeast": "Southeast US",
+    "southernplains": "Southern Plains US",
+    "southwest": "Southwestern US",
 }
 
 txt2drct = {
@@ -694,6 +714,10 @@ DATADIR = os.sep.join([os.path.dirname(__file__), "data", "reference"])
 # The below are dynamically generated on-demand, but are hard coded here
 # so that code introspection works.  Likely a better way!
 shef_physical_codes = {}
+shef_send_codes = {}
+shef_english_units = {}
+shef_standard_units = {}
+shef_table7 = {}
 state_names = {}
 prodDefinitions = {}
 ncei_state_codes = {}
@@ -707,7 +731,11 @@ class Wrapper:
     """Some Magic Here."""
 
     _onthefly_dict = [
+        "shef_english_units",
+        "shef_standard_units",
         "shef_physical_codes",
+        "shef_send_codes",
+        "shef_table7",
         "state_names",
         "prodDefinitions",
         "ncei_state_codes",
