@@ -14,9 +14,15 @@ import re
 import warnings
 import getpass
 from socket import error as socket_error
+import subprocess
+import tempfile
 
 # third party
+import psycopg2
+from psycopg2.extensions import register_adapter, AsIs
+import numpy as np
 from metpy.units import units, masked_array
+import requests
 
 # NB: some third party stuff is expensive to import, so let us be lazy
 
@@ -29,6 +35,18 @@ LOG = logging.getLogger("pyiem")
 LOG.addHandler(logging.NullHandler())
 
 
+def _addapt_num(val):
+    """Take the value verbatim."""
+    if not np.isnan(val):
+        return AsIs(val)
+    return AsIs("NULL")
+
+
+register_adapter(np.float64, _addapt_num)
+register_adapter(np.int64, _addapt_num)
+register_adapter(float, _addapt_num)
+
+
 class CustomFormatter(logging.Formatter):
     """A custom log formatter class."""
 
@@ -44,6 +62,69 @@ class CustomFormatter(logging.Formatter):
         )
 
 
+def web2ldm(url, ldm_product_name, md5_from_name=False, pqinsert="pqinsert"):
+    """Download a URL and insert into LDM.
+
+    Implements a common IEM workflow whereby a web resource is downloaded,
+    saved to a temporary file, and then inserted into LDM.
+
+    Args:
+      url (str): Web resource to download.
+      ldm_product_name (str): LDM product ID to use when inserting.
+      md5_from_name (bool): Should `pqinsert -i` be used, which causes LDM
+       to compute the MD5 value from the product name instead of data bytes.
+      pqinsert (str): pqinsert command.
+
+    Returns:
+      bool - success of this workflow.
+    """
+    req = requests.get(url, timeout=60)
+    if req.status_code != 200:
+        return False
+    tmp = tempfile.NamedTemporaryFile(mode="wb", delete=False)
+    tmp.write(req.content)
+    tmp.close()
+    args = [pqinsert, "-p", ldm_product_name, tmp.name]
+    if md5_from_name:
+        args.insert(1, "-i")
+    try:
+        proc = subprocess.Popen(
+            args,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        stderr = proc.stderr.read()
+        res = True
+        if stderr != b"":
+            LOG.info("pqinsert stderr result %s", stderr)
+            res = False
+    except FileNotFoundError:
+        LOG.info("Failed to find `pqinsert` in $PATH")
+        res = False
+
+    os.unlink(tmp.name)
+    return res
+
+
+def load_geodf(dataname):
+    """Load a given bundled GeoDataFrame.
+
+    Args:
+      dataname (str): The name of the dataset name to load.
+
+    Returns:
+      GeoDataFrame
+    """
+    import geopandas as gpd
+
+    datadir = os.sep.join([os.path.dirname(__file__), "data"])
+    fn = f"{datadir}/geodf/{dataname}.parquet"
+    if not os.path.isfile(fn):
+        LOG.info("load_geodf(%s) failed, file is missing!", fn)
+        return gpd.GeoDataFrame()
+    return gpd.read_parquet(fn)
+
+
 def convert_value(val, units_in, units_out):
     """DRY Helper to return magnitude of a metpy unit conversion.
 
@@ -84,7 +165,7 @@ def mm2inch(val):
 
 
 def html_escape(val):
-    """Wrapper around cgi.escape depreciation."""
+    """Wrapper around cgi.escape deprecation."""
     from html import escape
 
     return escape(val)
@@ -125,8 +206,6 @@ def logger(name="pyiem", level=None):
 
 def find_ij(lons, lats, lon, lat):
     """Compute the i,j closest cell."""
-    import numpy as np
-
     dist = ((lons - lon) ** 2 + (lats - lat) ** 2) ** 0.5
     (xidx, yidx) = np.unravel_index(dist.argmin(), dist.shape)
     return xidx, yidx
@@ -238,13 +317,10 @@ def get_dbconn(database="mesosite", user=None, host=None, port=5432, **kwargs):
       port (int,optional): the TCP port that PostgreSQL is listening
         defaults to 5432
       password (str,optional): the password to use.
-      allow_failover (bool,optional): Should this method attempt to connect to
-        a failover host (hard coded as iemdb2.local), default is `True`.
 
     Returns:
       psycopg2 database connection
     """
-    import psycopg2
 
     if user is None:
         user = getpass.getuser()
@@ -266,7 +342,6 @@ def get_dbconn(database="mesosite", user=None, host=None, port=5432, **kwargs):
         "connect_timeout": kwargs.get("connect_timeout", 15),
         "gssencmode": kwargs.get("gssencmode", "disable"),
     }
-    allow_failover = kwargs.pop("allow_failover", True)
     conn_kwargs.update(kwargs)
     attempt = 0
     while attempt < 3:
@@ -284,13 +359,10 @@ def get_dbconn(database="mesosite", user=None, host=None, port=5432, **kwargs):
             if attempt == 3:
                 raise exp
         except psycopg2.OperationalError as exp:
-            # as a stop-gap, lets try connecting to iemdb2
-            host2 = "iemdb2.local" if allow_failover else host
-            conn_kwargs["host"] = host2
             if attempt == 3:
                 raise exp
             warnings.warn(
-                f"database connection failure: {exp}, trying {host2}",
+                f"database connection failure: {exp}, trying again",
                 stacklevel=2,
             )
 
@@ -326,7 +398,7 @@ def noaaport_text(text):
     return "\r\r\n".join(lines)
 
 
-def get_autoplot_context(fdict, cfg):
+def get_autoplot_context(fdict, cfg, enforce_optional=False):
     """Get the variables out of a dict of strings
 
     This helper for IEM autoplot gets values out of a dictionary of strings,
@@ -338,6 +410,8 @@ def get_autoplot_context(fdict, cfg):
     Args:
       fdict (dictionary): what was likely provided by `cgi.FieldStorage()`
       cfg (dictionary): autoplot value of get_description
+      enforce_optional (bool,optional): Should the `optional` flag be enforced
+
     Returns:
       dictionary of variable names and values, with proper types!
     """
@@ -350,7 +424,15 @@ def get_autoplot_context(fdict, cfg):
         maxval = opt.get("max")
         optional = opt.get("optional", False)
         value = fdict.get(name)
-        if optional and value is None and typ not in ["vtec_ps"]:
+        # vtec_ps is special since we have special logic to get its value
+        if (
+            optional
+            and typ != "vtec_ps"
+            and (
+                value is None
+                or (enforce_optional and fdict.get(f"_opt_{name}") != "on")
+            )
+        ):
             continue
         if typ in ["station", "zstation", "sid", "networkselect"]:
             # A bit of hackery here if we have a name ending in a number
@@ -549,8 +631,6 @@ def grid_bounds(lons, lats, bounds):
     Returns:
       [x0, y0, x1, y1]
     """
-    import numpy as np
-
     if len(lons.shape) == 1:
         # Do 1-d work
         (x0, x1) = np.digitize([bounds[0], bounds[2]], lons)
