@@ -1,10 +1,232 @@
 """Unit Tests"""
 
 import pytest
-from pyiem.nws.products.spcpts import parser, str2multipolygon, load_conus_data
+from pyiem.nws.products import parser
+from pyiem.nws.products.spcpts import (
+    str2multipolygon,
+    load_conus_data,
+    SPCPTS,
+)
+from pyiem.nws.products._outlook_util import debug_draw
 from pyiem.util import utc, get_test_file
 
 
+def test_invalid_awipsid():
+    """Test that exception is raised when passed invalid AWIPS ID."""
+    data = get_test_file("SPCPTS/PTSDY1_closed.txt")
+    with pytest.raises(ValueError):
+        SPCPTS(data.replace("PTSDY1", "XXXYYY"))
+
+
+def test_get_invalid_outlook_day():
+    """Test that we can accurately close off an unclosed polygon."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_closed.txt"))
+    assert prod.get_outlook("", "", -1) is None
+
+
+def test_100606_closed():
+    """Test that we can accurately close off an unclosed polygon."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_closed.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 572.878) < 0.01
+
+
+def test_130607_larger_than_conus():
+    """Test that we do not yield a multipolygon larger than the CONUS."""
+    # /products/outlook/archive/2013/day1otlk_20130607_1630.html
+    prod = parser(get_test_file("SPCPTS/PTSDY1_conus.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 4.719) < 0.01
+
+
+def test_issue246():
+    """Test a segment that slightly leaks outside the CONUS."""
+    prod = parser(get_test_file("SPCPTS/PTSDY2_greatlakes.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "MRGL", 2)
+    assert abs(outlook.geometry.area - 165.72) < 0.01
+
+
+def test_880324_largerslight():
+    """Test that we discard a polygon that is larger than TSTM."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_larger.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 340.537) < 0.01
+
+
+def test_210501_multipolygon():
+    """Test that we handle a polygon that gets clipped into two chunks."""
+    # /products/outlook/archive/2021/day1otlk_20210501_1300.html
+    prod = parser(get_test_file("SPCPTS/PTSDY1_multipoly.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 238.516) < 0.01
+
+
+def test_debugdraw():
+    """Test we can draw a segment."""
+    load_conus_data()
+    assert debug_draw(0, [[10, 10], [20, 20]]) is not None
+
+
+def test_drawoutlooks():
+    """Test that we can draw an outlook."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_maine2.txt"))
+    prod.draw_outlooks()
+
+
+def test_issue466_maine2():
+    """Test that we can handle this harry logic."""
+    # /products/outlook/archive/2021/day1otlk_20210602_1300.html
+    prod = parser(get_test_file("SPCPTS/PTSDY1_maine2.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 469.71) < 0.01
+
+
+def test_210703_topoerror():
+    """Test that we do not get an exception for this."""
+    # /products/outlook/archive/2021/day1otlk_20210703_2000.html
+    prod = parser(get_test_file("SPCPTS/PTSDY1_topo2.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 452.077) < 0.01
+
+
+def test_210601_hole():
+    """Test that we properly get a hole with the TSTM."""
+    # /products/outlook/archive/2021/day1otlk_20210601_1300.html
+    prod = parser(get_test_file("SPCPTS/PTSDY1_hole.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 315.286) < 0.01
+
+
+def test_210601_last():
+    """Test that the last polygon does not dangle in complex logic."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_last.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 287.92) < 0.01
+
+
+def test_210519_singlepoint():
+    """Test that we handle when a single point is in the PTS."""
+    prod = parser(get_test_file("SPCPTS/PTSDY2_single.txt"))
+    outlook = prod.get_outlook("HAIL", "0.05", 2)
+    assert abs(outlook.geometry.area - 130.139) < 0.01
+
+
+def test_890526_multi():
+    """Test that we can process this PTS."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_multi.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "SLGT", 1)
+    assert abs(outlook.geometry.area - 111.132) < 0.01
+
+
+def test_210501_day2_west_coast():
+    """Test that we do not light up the west coast."""
+    # https://.../products/outlook/archive/2021/day2otlk_20210501_1730.html
+    prod = parser(get_test_file("SPCPTS/PTSDY2_canada.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 2)
+    assert abs(outlook.geometry.area - 351.342) < 0.01
+
+
+def test_210427_day1_west_coast():
+    """Test that we do not light up the west coast."""
+    # https://.../products/outlook/archive/2021/day1otlk_20210427_1630.html
+    prod = parser(get_test_file("SPCPTS/PTSDY1_west.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 359.536) < 0.01
+
+
+def test_210409_day2_invalid_geom():
+    """Test why this outlook bombed for me."""
+    prod = parser(get_test_file("SPCPTS/PTSDY2_invalid3.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 2)
+    assert abs(outlook.geometry.area - 212.9588) < 0.01
+
+
+def test_three():
+    """Test for a three intersection."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_three.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "MDT", 1)
+    assert abs(outlook.geometry.area - 31.511) < 0.01
+
+
+def test_sequence():
+    """Test for a bad sequence of multipolygons."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_sequence.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "MDT", 1)
+    assert abs(outlook.geometry.area - 28.441) < 0.01
+
+
+def test_badpoly3():
+    """Test that we can get a slight risk from this."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_badpoly3.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "SLGT", 1)
+    assert abs(outlook.geometry.area - 14.532) < 0.01
+
+
+def test_badpoly2():
+    """Test that we can get a slight risk from this."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_badpoly2.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "SLGT", 1)
+    assert abs(outlook.geometry.area - 47.538) < 0.01
+
+
+def test_badpoly():
+    """Test that we don't get a bad polygon out of this."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_badpoly.txt"))
+    outlook = prod.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 271.45) < 0.01
+
+
+def test_nogeom4():
+    """Test that we can get a slight risk from this."""
+    prod = parser(get_test_file("SPCPTS/PTSDY2_nogeom4.txt"))
+    # prod.draw_outlooks()
+    outlook = prod.get_outlook("CATEGORICAL", "SLGT", 2)
+    assert abs(outlook.geometry.area - 31.252) < 0.01
+
+
+def test_may3():
+    """Test that we can do something with the may 3, 1999 PTS."""
+    prod = parser(get_test_file("SPCPTS/PTSDY1_may3.txt"))
+    assert prod is not None
+
+
+def test_pfwfd2():
+    """Test parsing of a fire weather data2 product."""
+    text = get_test_file("SPCPTS/PFWFD2.txt")
+    prod = parser(text)
+    prod.get_jabbers("")
+    assert prod.cycle == 18
+    prod = parser(text.replace("0221 PM", "0721 AM"))
+    assert prod.cycle == 8
+    prod = parser(text.replace("0221 PM", "0821 AM"))
+    assert prod.cycle == -1
+
+
+@pytest.mark.parametrize("database", ["postgis"])
+def test_cycle(dbcursor):
+    """Test that we get the cycle right."""
+    ans = None
+    for i in [1, 3, 2]:  # Run out of order to test some canonical logic
+        prod = parser(get_test_file(f"SPCPTS/PTSDY1_20Z_{i}.txt"))
+        prod.sql(dbcursor)
+        if i == 3:
+            ans = prod.get_product_id()
+    # Check that we have only one canonical and that it is the last prod
+    dbcursor.execute(
+        "SELECT product_id from spc_outlook where cycle = 20 and "
+        "day = 1 and outlook_type = 'C' and expire = '2002-12-20 12:00+00'"
+    )
+    assert dbcursor.rowcount == 1
+    assert dbcursor.fetchone()[0] == ans
+
+
 @pytest.mark.parametrize("database", ["postgis"])
 def test_product_id_roundtrip(dbcursor):
     """Test that the product_id is persisted to the database."""
@@ -19,7 +241,9 @@ def test_product_id_roundtrip(dbcursor):
 
 def test_170619_maine():
     """Test that we don't light up all of Main for the slight."""
+    # https://.../products/outlook/archive/2017/day1otlk_20170619_1200.html
     spc = parser(get_test_file("SPCPTS/PTSDY1_maine.txt"))
+    # spc.draw_outlooks()
     outlook = spc.get_outlook("CATEGORICAL", "SLGT", 1)
     assert abs(outlook.geometry.area - 49.058) < 0.01
 
@@ -34,7 +258,7 @@ def test_issue295_geometryfail():
     )
     load_conus_data(utc(2020, 9, 26))
     res = str2multipolygon(s)
-    assert abs(res[0].area - 21.09) < 0.001
+    assert abs(res[0].area - 21.0814) < 0.001
 
 
 def test_200602_unpack():
@@ -57,10 +281,11 @@ def test_200109_nogeoms():
 
 def test_190907_invalid():
     """Product hit geos issue."""
+    # /products/outlook/archive/2019/day1otlk_20190907_1300.html
     spc = parser(get_test_file("SPCPTS/PTSDY1_190907.txt"))
     # spc.draw_outlooks()
     outlook = spc.get_outlook("CATEGORICAL", "TSTM", 1)
-    assert abs(outlook.geometry.area - 314.76) < 0.01
+    assert abs(outlook.geometry.area - 314.761) < 0.01
 
 
 def test_190905_invalid():
@@ -101,7 +326,7 @@ def test_190527_canada():
     spc = parser(get_test_file("SPCPTS/PTSDY1_canada.txt"))
     # spc.draw_outlooks()
     outlook = spc.get_outlook("CATEGORICAL", "MRGL", 1)
-    assert abs(outlook.geometry.area - 118.245) < 0.01
+    assert abs(outlook.geometry.area - 118.229) < 0.01
 
 
 def test_190515_issue117_month():
@@ -122,6 +347,7 @@ def test_190509_marinebounds():
 def test_190415_elevated():
     """Can we parse elevated threshold firewx?"""
     spc = parser(get_test_file("SPCPTS/PFWFD1_example.txt"))
+    spc.get_jabbers("")
     outlook = spc.get_outlook("FIRE WEATHER CATEGORICAL", "ELEV", 1)
     assert abs(outlook.geometry.area - 145.64) < 0.01
     for level in ["IDRT", "SDRT", "ELEV", "CRIT", "EXTM"]:
@@ -129,12 +355,6 @@ def test_190415_elevated():
         assert outlook is not None
 
 
-def test_190415_badtime():
-    """This product has a bad time period, we should emit a warning."""
-    spc = parser(get_test_file("SPCPTS/PTSDY1_invalidtime.txt"))
-    assert any([w.startswith("time_bounds_check") for w in spc.warnings])
-
-
 def test_180807_idx1_idx2():
     """This Day1 generated an error."""
     spc = parser(get_test_file("SPCPTS/PTSDY1_idx1_idx2.txt"))
@@ -164,7 +384,7 @@ def test_170703_badday3link():
         "https://www.spc.noaa.gov/products/outlook/archive/2013/"
         "day3otlk_20131119_0830.html"
     )
-    assert jdict[0][0] == ans
+    assert jdict[-1][0] == ans
 
 
 @pytest.mark.parametrize("database", ["postgis"])
@@ -196,12 +416,11 @@ def test_170518_bad_dbtime():
 @pytest.mark.parametrize("database", ["postgis"])
 def test_170428_large(dbcursor):
     """PTSDY1 has a large 10 tor"""
-    # https://.../products/outlook/archive/2006/day1otlk_20060510_1630.html
+    # /products/outlook/archive/2006/day1otlk_20060510_1630.html
     spc = parser(get_test_file("SPCPTS/PTSDY1_largetor10.txt"))
     # spc.draw_outlooks()
     spc.sql(dbcursor)
     outlook = spc.get_outlook("TORNADO", "0.10", 1)
-    assert abs(outlook.geometry.area - 31.11) < 0.01
     outlook = spc.get_outlook("CATEGORICAL", "TSTM", 1)
     assert abs(outlook.geometry.area - 428.00) < 0.01
 
@@ -219,7 +438,13 @@ def test_170417_empty(dbcursor):
         "https://www.spc.noaa.gov/products/exper/day4-8/archive/"
         "2008/day4-8_20081225.html"
     )
-    assert jabber[0][0] == ans
+    assert jabber[-1][0] == ans
+    ans = (
+        "https://mesonet.agron.iastate.edu/plotting/auto/plot/220/"
+        "cat:categorical::which:0C::t:conus::network:WFO::wfo:DMX::"
+        "csector:conus::valid:2008-12-25%200941.png"
+    )
+    assert jabber[-1][2]["twitter_media"] == ans
 
 
 @pytest.mark.parametrize("database", ["postgis"])
@@ -228,10 +453,6 @@ def test_051128_invalid(dbcursor):
     spc = parser(get_test_file("SPCPTS/PTSDY1_biggeom2.txt"))
     # spc.draw_outlooks()
     spc.sql(dbcursor)
-    # Both of these are invalidly provided in the PTS file and should be
-    # dumped as they are larger than the general thunder
-    outlook = spc.get_outlook("WIND", "SIGN", 1)
-    assert outlook.geometry.is_empty
     outlook = spc.get_outlook("WIND", "0.05", 1)
     assert outlook.geometry.is_empty
     print("\n".join(spc.warnings))
@@ -243,8 +464,7 @@ def test_080731_invalid():
     spc = parser(get_test_file("SPCPTS/PTSDY1_biggeom.txt"))
     # spc.draw_outlooks()
     outlook = spc.get_outlook("WIND", "SIGN", 1)
-    assert abs(outlook.geometry.area - 15.82) < 0.01
-    assert len(spc.warnings) == 1
+    assert abs(outlook.geometry.area - 15.823) < 0.01
 
 
 def test_170411_jabber_error():
@@ -256,7 +476,7 @@ def test_170411_jabber_error():
         "Weather Outlook at Apr 11, 19:54z "
         "https://www.spc.noaa.gov/products/exper/fire_wx/2017/170413.html"
     )
-    assert j[0][0] == ans
+    assert j[-1][0] == ans
 
 
 @pytest.mark.parametrize("database", ["postgis"])
@@ -288,7 +508,7 @@ def test_170404_nogeom():
     """nogeom error from a 2002 product"""
     # 26 Sep 2017, we can workaround this now
     spc = parser(get_test_file("SPCPTS/PTSDY1_2002_nogeom.txt"))
-    outlook = spc.get_outlook("TORNADO", "0.05")
+    outlook = spc.get_outlook("TORNADO", "0.05", 1)
     assert abs(outlook.geometry.area - 8.76) < 0.01
 
 
@@ -296,7 +516,7 @@ def test_170404_2002():
     """Can we parse something from 2002?"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_2002.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("CATEGORICAL", "SLGT")
+    outlook = spc.get_outlook("CATEGORICAL", "SLGT", 1)
     assert abs(outlook.geometry.area - 38.614) < 0.01
 
 
@@ -304,7 +524,7 @@ def test_170329_notimp():
     """Exception was raised parsing this guy"""
     spc = parser(get_test_file("SPCPTS/PTSDY2_notimp.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("CATEGORICAL", "MRGL")
+    outlook = spc.get_outlook("CATEGORICAL", "MRGL", 2)
     assert abs(outlook.geometry.area - 110.24) < 0.01
 
 
@@ -312,15 +532,15 @@ def test_170215_gh23():
     """A marginal for the entire country :/"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_gh23.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("CATEGORICAL", "MRGL")
+    outlook = spc.get_outlook("CATEGORICAL", "MRGL", 1)
     assert abs(outlook.geometry.area - 19.63) < 0.01
 
 
 def test_150622_ptsdy1_topo():
-    """PTSDY1_topo.txt """
+    """PTSDY1_topo.txt"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_topo.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("CATEGORICAL", "SLGT")
+    outlook = spc.get_outlook("CATEGORICAL", "SLGT", 1)
     assert abs(outlook.geometry.area - 91.91) < 0.01
 
 
@@ -328,40 +548,40 @@ def test_150622_ptsdy2():
     """PTSDY2_invalid.txt parsed ok."""
     spc = parser(get_test_file("SPCPTS/PTSDY2_invalid.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("CATEGORICAL", "SLGT")
+    outlook = spc.get_outlook("CATEGORICAL", "SLGT", 2)
     assert abs(outlook.geometry.area - 78.14) < 0.01
 
 
 def test_150622_ptsdy1():
-    """PTSDY1_nogeom.txt """
+    """PTSDY1_nogeom.txt"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_nogeom.txt"))
-    outlook = spc.get_outlook("CATEGORICAL", "SLGT")
-    assert abs(outlook.geometry.area - 95.900) < 0.01
+    outlook = spc.get_outlook("CATEGORICAL", "SLGT", 1)
+    assert abs(outlook.geometry.area - 95.912) < 0.01
 
 
 def test_150612_ptsdy1_3():
     """We got an error with this, so we shall test"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_3.txt"))
-    outlook = spc.get_outlook("CATEGORICAL", "SLGT")
+    outlook = spc.get_outlook("CATEGORICAL", "SLGT", 1)
     assert abs(outlook.geometry.area - 53.94) < 0.01
 
 
 def test_141022_newcats():
-    """ Make sure we can parse the new categories """
+    """Make sure we can parse the new categories"""
     spc = parser(
         get_test_file("SPCPTS/PTSDY1_new.txt"),
         utcnow=utc(2014, 10, 13, 16, 21),
     )
-    outlook = spc.get_outlook("CATEGORICAL", "ENH")
+    outlook = spc.get_outlook("CATEGORICAL", "ENH", 1)
     assert abs(outlook.geometry.area - 13.02) < 0.01
-    outlook = spc.get_outlook("CATEGORICAL", "MRGL")
+    outlook = spc.get_outlook("CATEGORICAL", "MRGL", 1)
     assert abs(outlook.geometry.area - 47.01) < 0.01
 
 
 def test_140709_nogeoms():
     """Can we parse holes."""
     spc = parser(get_test_file("SPCPTS/PTSDY3_nogeoms.txt"))
-    outlook = spc.get_outlook("ANY SEVERE", "0.05")
+    outlook = spc.get_outlook("ANY SEVERE", "0.05", 3)
     assert abs(outlook.geometry.area - 99.68) < 0.01
 
 
@@ -369,12 +589,12 @@ def test_140710_nogeom():
     """Can we parse holes."""
     spc = parser(get_test_file("SPCPTS/PTSDY2_nogeom.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("CATEGORICAL", "SLGT")
+    outlook = spc.get_outlook("CATEGORICAL", "SLGT", 2)
     assert abs(outlook.geometry.area - 43.02) < 0.01
 
 
 def test_23jul_failure():
-    """ CCW line near Boston """
+    """CCW line near Boston"""
     # need to load data for this to work as a one
     load_conus_data(utc(2017, 7, 23))
     data = """40067377 40567433 41317429 42097381 42357259 42566991"""
@@ -383,24 +603,23 @@ def test_23jul_failure():
 
 
 def test_140707_general():
-    """ Had a problem with General Thunder, lets test this """
-    # https://.../products/outlook/archive/2014/day1otlk_20140707_1630.html
+    """Had a problem with General Thunder, lets test this"""
+    # /products/outlook/archive/2014/day1otlk_20140707_1630.html
     spc = parser(get_test_file("SPCPTS/PTSDY1_complex.txt"))
     # spc.draw_outlooks()
-    # Linework here is invalid, so we can't account for it.
-    outlook = spc.get_outlook("CATEGORICAL", "TSTM")
-    assert abs(outlook.geometry.area - 755.424) < 0.01
+    outlook = spc.get_outlook("CATEGORICAL", "TSTM", 1)
+    assert abs(outlook.geometry.area - 606.333) < 0.01
 
 
 def test_complex():
-    """ Test our processing """
+    """Test our processing"""
     spc = parser(get_test_file("SPCPTS/PTSDY3.txt"))
-    outlook = spc.get_outlook("ANY SEVERE", "0.05")
+    outlook = spc.get_outlook("ANY SEVERE", "0.05", 3)
     assert abs(outlook.geometry.area - 10.12) < 0.01
 
 
 def test_bug_140601_pfwf38():
-    """ Encounted issue with Fire Outlook Day 3-8 """
+    """Encounted issue with Fire Outlook Day 3-8"""
     spc = parser(get_test_file("SPCPTS/PFWF38.txt"))
     # spc.draw_outlooks()
     collect = spc.get_outlookcollection(3)
@@ -408,7 +627,7 @@ def test_bug_140601_pfwf38():
 
 
 def test_bug_140507_day1():
-    """ Bug found in production with GEOS Topology Exception """
+    """Bug found in production with GEOS Topology Exception"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_topoexp.txt"))
     # spc.draw_outlooks()
     collect = spc.get_outlookcollection(1)
@@ -428,11 +647,18 @@ def test_bug_140506_day2():
         "https://www.spc.noaa.gov/products/outlook/archive/2014/"
         "day2otlk_20140506_1730.html"
     )
-    assert j[0][0] == ans
+    assert j[-1][0] == ans
+    ans = (
+        "https://mesonet.agron.iastate.edu/plotting/auto/plot/220/"
+        "cat:categorical::which:2C::t:conus::network:WFO::wfo:TSA::"
+        "csector:conus::valid:2014-05-06%201731.png"
+    )
+    assert j[-1][2]["twitter_media"] == ans
 
 
 def test_bug_140518_day2():
-    """ 18 May 2014 tripped error with no exterior polygon found """
+    """18 May 2014 tripped error with no exterior polygon found"""
+    # /products/outlook/archive/2014/day2otlk_20140518_0600.html
     spc = parser(get_test_file("SPCPTS/PTSDY2_interior.txt"))
     # spc.draw_outlooks()
     collect = spc.get_outlookcollection(2)
@@ -440,7 +666,7 @@ def test_bug_140518_day2():
 
 
 def test_bug_140519_day1():
-    """ 19 May 2014 tripped error with no exterior polygon found """
+    """19 May 2014 tripped error with no exterior polygon found"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_interior.txt"))
     # spc.draw_outlooks()
     collect = spc.get_outlookcollection(1)
@@ -448,23 +674,23 @@ def test_bug_140519_day1():
 
 
 def test_bug():
-    """ Test bug list index outof range """
+    """Test bug list index outof range"""
     spc = parser(get_test_file("SPCPTS/PTSDY1_2.txt"))
     collect = spc.get_outlookcollection(1)
     assert len(collect.outlooks) == 1
 
 
 def test_complex_2():
-    """ Test our processing """
+    """Test our processing"""
     spc = parser(get_test_file("SPCPTS/PTSDY1.txt"))
     # spc.draw_outlooks()
-    outlook = spc.get_outlook("HAIL", "0.05")
+    outlook = spc.get_outlook("HAIL", "0.05", 1)
     assert abs(outlook.geometry.area - 47.65) < 0.01
 
 
 @pytest.mark.parametrize("database", ["postgis"])
 def test_str1(dbcursor):
-    """ check spcpts parsing """
+    """check spcpts parsing"""
     spc = parser(get_test_file("SPCPTS/SPCPTS.txt"))
     # spc.draw_outlooks()
     assert spc.valid == utc(2013, 7, 19, 19, 52)
@@ -472,8 +698,5 @@ def test_str1(dbcursor):
     assert spc.expire == utc(2013, 7, 20, 12, 0)
 
     spc.sql(dbcursor)
-    spc.compute_wfos(dbcursor)
-    # It is difficult to get a deterministic result here as in Travis, we
-    # don't have UGCS, so the WFO lookup yields no results
     j = spc.get_jabbers("")
     assert len(j) >= 1
