@@ -8,32 +8,50 @@ import pytest
 import matplotlib.colors as mpcolors
 import numpy as np
 from pyiem import plot
-from pyiem.plot.geoplot import windrose
 from pyiem.plot import (
     MapPlot,
     centered_bins,
     pretty_bins,
     load_bounds,
-    load_pickle_pd,
-    load_geodf,
 )
 from pyiem.util import utc
 
-
-def test_depreciated():
-    """Test that our windrose is depreciated."""
-    with pytest.deprecated_call():
-        windrose("")
+PAIN = 1.1  # how much do we care, sigh.
 
 
 def test_invalid_file():
     """Test that we don't error out on an invalid filename."""
     assert load_bounds("this shall not work") is None
-    assert load_pickle_pd("this shall not work") is None
-    assert load_geodf("this shall not work").empty
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_nws_sector_twitter_res():
+    """Test that Hawaii does not overlap Florida for Twitter Res."""
+    mp = MapPlot(
+        twitter=True,
+        nocaption=True,
+        sector="nws",
+        title="Don't hide Flo Rida",
+    )
+    mp.draw_cwas()
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_nashville():
+    """Test that Benton County, TNC005 does not show for OHX."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="cwa",
+        cwa="OHX",
+        title="Don't show Benton County TN!",
+    )
+    mp.fill_ugcs({"TNC005": 10}, plotmissing=True)
+    mp.draw_cwas()
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_plotmissing():
     """Test that we can plotmissing."""
     mp = MapPlot(
@@ -46,7 +64,7 @@ def test_plotmissing():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_fill_by_str():
     """Test that we can fill by string or dict."""
     mp = MapPlot(
@@ -59,7 +77,7 @@ def test_fill_by_str():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_fill_by_dict():
     """Test that we can fill by string or dict."""
     mp = MapPlot(
@@ -72,7 +90,7 @@ def test_fill_by_dict():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_issue374_pah():
     """Test drawing fire weather zones for Paducah."""
     mp = MapPlot(
@@ -85,7 +103,7 @@ def test_issue374_pah():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_memphis_cwa():
     """Test that we can draw a map with Memphis CWA.."""
     mp = MapPlot(
@@ -98,7 +116,7 @@ def test_memphis_cwa():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_overlay_roadcond():
     """Test being able to plot Iowa Road Conditions."""
     mp = MapPlot(
@@ -110,7 +128,7 @@ def test_overlay_roadcond():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_overlay_nexrad():
     """Test being able to plot NEXRAD."""
     mp = MapPlot(
@@ -122,7 +140,7 @@ def test_overlay_nexrad():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_overlay_nexrad_hawaii():
     """Test that we can plot nexrad over Hawaii."""
     mp = MapPlot(
@@ -131,11 +149,12 @@ def test_overlay_nexrad_hawaii():
         state="HI",
         title="A long and long title that has no purpose but to test things",
     )
-    mp.overlay_nexrad(utc(2021, 2, 9, 17))
+    caxpos = [0.05, 0.05, 0.35, 0.015]
+    mp.overlay_nexrad(utc(2021, 2, 9, 17), caxpos=caxpos)
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_overlay_nexrad_alaska():
     """Test that we can plot nexrad over Alaska."""
     mp = MapPlot(
@@ -148,7 +167,7 @@ def test_overlay_nexrad_alaska():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_overlay_nexrad_puerto_rico():
     """Test that we can plot nexrad over Puerto Rico."""
     mp = MapPlot(
@@ -161,7 +180,7 @@ def test_overlay_nexrad_puerto_rico():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_conus_contour():
     """Test that a conus sector plot can generate a contour correctly."""
     mp = MapPlot(nocaption=True, sector="conus", twitter=True)
@@ -176,7 +195,7 @@ def test_conus_contour():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_issue365_cape_cod():
     """Test that we don't mask out Cape Cod."""
     mp = MapPlot(nocaption=True, sector="cwa", cwa="BOX")
@@ -192,21 +211,21 @@ def test_issue365_cape_cod():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_issue217():
     """See what happens with our logo on very scaled figure."""
     mp = MapPlot(nocaption=True, figsize=(6.00, 3.35))
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_twitter_resolution():
     """Test that we get good plot domain when we want a twitter resolution."""
     mp = MapPlot(sector="conus", nocaption=True, twitter=True)
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN + 1)  # lots of bars
 def test_issue98_labelbar():
     """Sometimes our label bar sucks."""
     mp = MapPlot(
@@ -239,7 +258,7 @@ def test_savefile():
     assert os.path.isfile(tmpfd.name)
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_illinois():
     """Produce a plot that doesn't suck"""
     mp = MapPlot(sector="state", state="IL", nocaption=True)
@@ -247,7 +266,7 @@ def test_illinois():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_issue292_nws_fill_ugcs():
     """Test that fill_ugcs works for nws sector view."""
     mp = MapPlot(sector="nws", title="Four Counties", nocaption=True)
@@ -256,7 +275,7 @@ def test_issue292_nws_fill_ugcs():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_fill_ugcs_color():
     """Provide an explicit color to fill_ugcs"""
     mp = MapPlot(
@@ -269,7 +288,7 @@ def test_fill_ugcs_color():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_dep():
     """Produce a plot with the DEP logo on it."""
     mp = MapPlot(sector="state", state="IA", nocaption=True, logo="dep")
@@ -284,7 +303,7 @@ def test_usdm():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_hexbin():
     """See if we can do hexbin OKish"""
     mp = MapPlot(
@@ -306,7 +325,7 @@ def test_hexbin():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.2)
+@pytest.mark.mpl_image_compare(tolerance=10)  # Lots of one pixel diffs
 def test_pcolormesh():
     """See if we can do pcolormesh OKish"""
     mp = MapPlot(
@@ -352,7 +371,7 @@ def test_centered_bins():
     assert abs(a[-1] - 1.6) < 0.001
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_michigan():
     """See what we do with Michigan"""
     mp = MapPlot(sector="state", state="MI", nocaption=True)
@@ -366,7 +385,7 @@ def test_michigan():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_drawcities():
     """Draw Cities"""
     mp = MapPlot(
@@ -380,7 +399,7 @@ def test_drawcities():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_drawrandomtext():
     """See if we can handle the fun that is drawing random text"""
     mp = MapPlot(
@@ -399,7 +418,7 @@ def test_drawrandomtext():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.2)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_drawiowawfo():
     """Iowa Contour Plot"""
     mp = MapPlot(sector="iowawfo", title="Iowa Contour plot", nocaption=True)
@@ -413,7 +432,7 @@ def test_drawiowawfo():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.3)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_fillstates():
     """Can we fill states"""
     data = {"AK": 10, "HI": 30, "IA": 40, "NY": 80}
@@ -443,7 +462,7 @@ def test_drawcounties_cornbelt():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.25)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_drawcounties_iailin():
     """draw IA IL IN masked"""
     mp = MapPlot(sector="iailin", title="Counties", nocaption=True)
@@ -467,7 +486,7 @@ def test_climdiv():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_colorbar():
     """Run tests against the colorbar algorithm"""
     mp = MapPlot(sector="iowa", nocaption=True)
@@ -480,7 +499,7 @@ def test_colorbar():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_colorbar2():
     """draw a colorbar"""
     mp = MapPlot(sector="iowa", nocaption=True)
@@ -506,7 +525,7 @@ def test_colorbar2():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_colorbar3():
     """draw another colorbar"""
     mp = MapPlot(sector="iowa", nocaption=True)
@@ -545,7 +564,20 @@ def test_drawugcs2():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_lwx_cities():
+    """Test that cities plot in a reasonable spot."""
+    mp = MapPlot(
+        sector="cwa",
+        cwa="LWX",
+        title="DC should be where DC is",
+        nocaption=True,
+    )
+    mp.drawcities()
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_ugcs_lwx():
     """Ensure that we can plot some counties in LWX CWA."""
     mp = MapPlot(
@@ -566,7 +598,7 @@ def test_ugcs_lwx():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_ugcs_lwx_zones():
     """Ensure that we can plot some zones in LWX CWA."""
     mp = MapPlot(
@@ -587,7 +619,7 @@ def test_ugcs_lwx_zones():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN + 1)  # lots of bars on plot
 def test_ugcs_withcustomlabels():
     """Fill ugcs with provided labels."""
     mp = MapPlot(
@@ -614,7 +646,7 @@ def test_ugcs_withcustomlabels():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.15)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_states():
     """Exercise the state plotting routines"""
     mp = MapPlot(sector="state", state="CA", nocaption=True)
@@ -640,7 +672,7 @@ def test_cwa_with_custom_masking():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_cwa():
     """Exercise the cwa plotting routines"""
     mp = MapPlot(sector="cwa", cwa="MKX", nocaption=True)
@@ -671,7 +703,7 @@ def test_colorramps():
 
 @pytest.mark.mpl_image_compare(tolerance=0.2)
 def test_overlap():
-    """ Do some checking of our overlaps logic """
+    """Do some checking of our overlaps logic"""
     mp = MapPlot(sector="midwest", continentalcolor="white", nocaption=True)
     lons = np.linspace(-99, -90, 100)
     lats = np.linspace(38, 44, 100)
@@ -681,7 +713,7 @@ def test_overlap():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_barbs():
     """Testing the plotting of wind barbs"""
     mp = MapPlot(continentalcolor="white", nocaption=True)
@@ -693,7 +725,7 @@ def test_barbs():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_stationplot():
     """Testing the plotting of wind barbs"""
     mp = MapPlot(continentalcolor="white", nocaption=True)
@@ -705,9 +737,9 @@ def test_stationplot():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.2)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_scatter():
-    """ Test scatter plots """
+    """Test scatter plots"""
     mp = MapPlot(
         sector="midwest",
         title="Should see 100 dots",
@@ -725,7 +757,7 @@ def test_scatter():
 
 @pytest.mark.mpl_image_compare(tolerance=4)
 def test_contourf():
-    """ Test the contourf plot with labels specified """
+    """Test the contourf plot with labels specified"""
     mp = MapPlot(sector="iowa", nocaption=True)
     mp.contourf(
         np.arange(-94, -89),
@@ -737,15 +769,15 @@ def test_contourf():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_textplot():
-    """ Can we plot text and place labels on them """
+    """Can we plot text and place labels on them"""
     mp = MapPlot(sector="iowa", nocaption=True)
     mp.plot_values(np.arange(-99, -94), np.arange(40, 45), np.arange(5))
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_textplot2():
     """plot values on a map"""
     mp = MapPlot(sector="iowa", nocaption=True)
@@ -760,7 +792,7 @@ def test_textplot2():
 
 @pytest.mark.mpl_image_compare(tolerance=1.0)
 def test_plot():
-    """ Exercise the API """
+    """Exercise the API"""
     mp = MapPlot(sector="midwest", nocaption=True)
     # test the translation of JSJ to SJU
     mp.fill_cwas({"DMX": 80, "MKX": 5, "JSJ": 30, "AJK": 40}, units="no units")
@@ -769,7 +801,7 @@ def test_plot():
 
 @pytest.mark.mpl_image_compare(tolerance=1.0)
 def test_plot2():
-    """ Exercise NWS plot API """
+    """Exercise NWS plot API"""
     mp = MapPlot(sector="nws", continentalcolor="white", nocaption=True)
     mp.fill_cwas(
         {"DMX": 80, "MKX": 5, "SJU": 30, "AJK": 40, "HFO": 50},
@@ -780,7 +812,7 @@ def test_plot2():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.63)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_plot22():
     """plot cwas that are filled"""
     mp = MapPlot(sector="iowa", continentalcolor="white", nocaption=True)
@@ -792,9 +824,9 @@ def test_plot22():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.2)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_plot3():
-    """ Exercise climdiv plot API """
+    """Exercise climdiv plot API"""
     mp = MapPlot(sector="iowa", nocaption=True)
     mp.fill_climdiv(
         {"IAC001": 80, "AKC003": 5, "HIC003": 30, "AJK": 40, "HFO": 50}
@@ -802,7 +834,7 @@ def test_plot3():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.1)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_alaska():
     """See that Alaska plots nicely."""
     mp = MapPlot(sector="state", state="AK", nocaption=True)
