@@ -23,6 +23,65 @@ def cursor():
     return util.get_dbconn("mesosite").cursor()
 
 
+def test_insert_nan(cursor):
+    """Test that we properly insert NaN values as nulls."""
+    vals = np.array([0, np.nan, 10], dtype=np.float64)
+    cursor.execute(
+        "INSERT into stations(iemid, remote_id) VALUES (%s, %s) "
+        "RETURNING remote_id",
+        (-100, vals[1]),
+    )
+    assert cursor.fetchone()[0] is None
+
+
+def test_web2ldm():
+    """Test that we can ingest something and insert it."""
+    assert util.web2ldm(
+        "http://mesonet.agron.iastate.edu/robots.txt",
+        str(util.utc()),
+        md5_from_name=True,
+        pqinsert="true",
+    )
+
+
+def test_web2ldm_dup():
+    """Test that we fail when inserting a duplicate."""
+    pqstr = str(util.utc())
+    util.web2ldm(
+        "http://mesonet.agron.iastate.edu/robots.txt",
+        pqstr,
+        md5_from_name=True,
+    )
+    assert not util.web2ldm(
+        "http://mesonet.agron.iastate.edu/robots.txt",
+        pqstr,
+        md5_from_name=True,
+    )
+
+
+def test_web2ldm_failed():
+    """Test for graceful failure when pqinsert fails."""
+    assert not util.web2ldm(
+        "http://mesonet.agron.iastate.edu/robots.txt",
+        "Blah",
+        md5_from_name=True,
+        pqinsert="cat",
+    )
+
+
+def test_web2ldm_badurl():
+    """Test for graceful failure when given a URL that will 404."""
+    assert not util.web2ldm(
+        "http://iastate.edu/not_existing",
+        "Blah",
+    )
+
+
+def test_invalid_file():
+    """Test that we don't error out on an invalid filename."""
+    assert util.load_geodf("this shall not work").empty
+
+
 @pytest.mark.parametrize("dbname", ["mos", "hads", "iemre", "postgis"])
 def test_get_dbconn(dbname):  # noqa
     """Does our code work for various database names."""
@@ -64,7 +123,7 @@ def test_get_dbconn_failover():
     """See if failover works?"""
     with pytest.warns(UserWarning, match="database connection failure"):
         with pytest.raises(psycopg2.OperationalError):
-            util.get_dbconn("mesosite", host="b", allow_failover=False)
+            util.get_dbconn("mesosite", host="b")
 
 
 def test_get_dbconn_bad_argument():
@@ -151,6 +210,18 @@ def test_get_autoplot_context_network():
         util.get_autoplot_context(form, cfg)
 
 
+def test_get_autoplot_context_optional():
+    """Test that we require the optional flag nomenclature."""
+    form = dict(year=2011)
+    opts = dict(
+        arguments=[
+            dict(type="year", name="year", optional=True, default=2012),
+        ]
+    )
+    ctx = util.get_autoplot_context(form, opts, enforce_optional=True)
+    assert "year" not in ctx
+
+
 def test_get_autoplot_context():
     """See that we can do things."""
     form = dict(type2="bogus", t=15, type3=["max-high", "bogus", "min-high"])
@@ -309,6 +380,7 @@ def test_vtecps():
     form = dict(
         phenomenav1="SV",
         significancev1="A",
+        _opt_v4="on",
         phenomenav4="TO",
         significancev4="W",
     )
@@ -333,7 +405,7 @@ def test_properties_nocursor():
 
 
 def test_properties(cursor):
-    """ Try the properties function"""
+    """Try the properties function"""
     tmpname = "".join(
         random.choice(string.ascii_uppercase + string.digits) for _ in range(7)
     )
@@ -350,7 +422,7 @@ def test_properties(cursor):
 
 
 def test_drct2text():
-    """ Test conversion of drct2text """
+    """Test conversion of drct2text"""
     assert util.drct2text(360) == "N"
     assert util.drct2text(90) == "E"
     assert util.drct2text(None) is None
